@@ -4,6 +4,7 @@ from datetime import datetime
 import json
 from bs4 import BeautifulSoup
 from .convert_pic import convert_pic
+from nonebot.log import logger
 
 
 async def get_update():
@@ -28,7 +29,7 @@ async def parse_html(uri):
         "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/95.0.4638.69 Safari/537.36 Edg/95.0.1020.53"
     }
     start_div = '<div class="section0 topindex">'
-    end_div = '<!-- <script type="text/javascript" src="js/index.js"></script>'
+    end_div = '<script type="text/javascript" src="js/index.js'
     tmp = []
     answer_attrs = {"required": [], "optional": []}
     option = "ABCDEF"
@@ -76,7 +77,7 @@ async def parse_html(uri):
                             field = "optional"
                             answer_attrs[field].append(v)
 
-                    print(answer_attrs)
+                    logger.info(answer_attrs)
                     # process
                     output = []
                     if len(answer_attrs["required"]) > 0:
